@@ -24,7 +24,6 @@
 #include "vinagre-bookmarks-ui.h"
 #include "vinagre-utils.h"
 #include "vinagre-bookmarks-tree.h"
-#include "vinagre-plugin.h"
 #include "vinagre-plugins-engine.h"
 
 static void
@@ -44,7 +43,7 @@ show_dialog_folder (VinagreBookmarks      *book,
   GtkWidget   *dialog, *box, *tree, *name_entry, *save_button;
   const gchar *name;
 
-  xml = vinagre_utils_get_builder ();
+  xml = vinagre_utils_get_builder (NULL);
   dialog     = GTK_WIDGET (gtk_builder_get_object (xml, "bookmarks_add_edit_folder_dialog"));
   name_entry = GTK_WIDGET (gtk_builder_get_object (xml, "edit_bookmark_folder_name_entry"));
   box        = GTK_WIDGET (gtk_builder_get_object (xml, "folder_box1"));
@@ -118,18 +117,18 @@ show_dialog_conn (VinagreBookmarks      *book,
 		  VinagreBookmarksEntry *entry,
 		  gboolean               is_add)
 {
-  gchar             *str, *host, *error_str, *protocol;
-  gint               port;
-  GtkBuilder        *xml;
-  GtkWidget         *dialog, *host_entry, *name_entry, *fs_check;
-  GtkWidget         *folder_box, *tree, *save_button, *plugin_box;
-  GtkWidget         *plugin_options, *protocol_label;
-  VinagreConnection *conn;
-  const gchar       *name;
-  VinagrePlugin     *plugin;
-  gchar             **props;
+  gchar              *str, *host, *error_str, *protocol;
+  gint                port;
+  GtkBuilder         *xml;
+  GtkWidget          *dialog, *host_entry, *name_entry, *fs_check;
+  GtkWidget          *folder_box, *tree, *save_button, *plugin_box;
+  GtkWidget          *plugin_options, *protocol_label;
+  VinagreConnection  *conn;
+  const gchar        *name;
+  VinagreProtocol    *ext;
+  gchar              **props;
 
-  xml = vinagre_utils_get_builder ();
+  xml = vinagre_utils_get_builder (NULL);
   dialog         = GTK_WIDGET (gtk_builder_get_object (xml, "bookmarks_add_edit_conn_dialog"));
   name_entry     = GTK_WIDGET (gtk_builder_get_object (xml, "edit_bookmark_name_entry"));
   host_entry     = GTK_WIDGET (gtk_builder_get_object (xml, "edit_bookmark_host_entry"));
@@ -155,15 +154,15 @@ show_dialog_conn (VinagreBookmarks      *book,
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (fs_check),
 				vinagre_connection_get_fullscreen (conn));
 
-  plugin = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
-							  vinagre_connection_get_protocol (conn));
-  plugin_options = vinagre_plugin_get_connect_widget (plugin, conn);
+  ext = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
+						       vinagre_connection_get_protocol (conn));
+  plugin_options = vinagre_protocol_get_connect_widget (ext, conn);
   if (plugin_options)
     gtk_box_pack_start (GTK_BOX (plugin_box), plugin_options, TRUE, TRUE, 0);
   else
     gtk_widget_hide (plugin_box);
 
-  props = vinagre_plugin_get_public_description (plugin);
+  props = vinagre_protocol_get_public_description (ext);
   /* Translators: %s is a protocol name, like VNC or SSH */
   str = g_strdup_printf (_("(Protocol: %s)"), props[0]);
   gtk_label_set_label (GTK_LABEL (protocol_label), str);
@@ -297,8 +296,6 @@ vinagre_bookmarks_del (VinagreBookmarks      *book,
 {
   GtkWidget *dialog;
   gchar     *name, *title, *msg1, *msg2;
-  GError    *error = NULL;
-  GSList    *parent;
 
   g_return_if_fail (VINAGRE_IS_BOOKMARKS (book));
   g_return_if_fail (VINAGRE_IS_BOOKMARKS_ENTRY (entry));
