@@ -24,11 +24,9 @@
 
 #include <glib/gi18n.h>
 
-#include "vinagre-notebook.h"
 #include "vinagre-utils.h"
 #include "vinagre-dnd.h"
 #include "vinagre-prefs.h"
-#include "vinagre-spinner.h"
 
 #define VINAGRE_NOTEBOOK_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), VINAGRE_TYPE_NOTEBOOK, VinagreNotebookPrivate))
 
@@ -180,7 +178,7 @@ drag_data_get_handl (GtkWidget *widget,
 
 	/*FIXME: Set other properties of the connection*/
 	gtk_selection_data_set (selection_data,
-				selection_data->target,
+				gtk_selection_data_get_target (selection_data),
 				8,
 				(guchar*) data,
 				strlen (data));
@@ -204,6 +202,7 @@ vinagre_notebook_update_ui_sentitivity (VinagreNotebook *nb)
 {
   gboolean       active;
   GtkActionGroup *action_group;
+  GtkAction      *action;
 
   active = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb)) > 0;
   action_group = vinagre_window_get_connected_action (nb->priv->window);
@@ -214,6 +213,11 @@ vinagre_notebook_update_ui_sentitivity (VinagreNotebook *nb)
 	   (vinagre_tab_get_state (VINAGRE_TAB (nb->priv->active_tab)) == VINAGRE_TAB_STATE_CONNECTED);
   gtk_action_group_set_sensitive (action_group, active);
 
+  action = gtk_action_group_get_action (action_group, "MachineTakeScreenshot");
+  gtk_action_set_sensitive (action, active &&
+				    nb->priv->active_tab &&
+				    vinagre_tab_get_has_screenshot (nb->priv->active_tab));
+
   if (nb->priv->active_tab)
     {
       GtkWidget *spinner, *icon;
@@ -224,14 +228,14 @@ vinagre_notebook_update_ui_sentitivity (VinagreNotebook *nb)
       if (vinagre_tab_get_state (VINAGRE_TAB (nb->priv->active_tab)) == VINAGRE_TAB_STATE_CONNECTED)
 	{
 	  gtk_widget_hide (spinner);
-	  vinagre_spinner_stop (VINAGRE_SPINNER (spinner));
+	  gtk_spinner_stop (GTK_SPINNER (spinner));
 	  gtk_widget_show (icon);
 	}
       else
 	{
 	  gtk_widget_hide (icon);
 	  gtk_widget_show (spinner);
-	  vinagre_spinner_start (VINAGRE_SPINNER (spinner));
+	  gtk_spinner_start (GTK_SPINNER (spinner));
 	}
     }
 }
@@ -360,10 +364,10 @@ unmerge_tab_ui (VinagreNotebook *nb)
 }
 
 static void 
-vinagre_notebook_page_switched (GtkNotebook     *notebook,
-				GtkNotebookPage *pg,
-				gint            page_num, 
-				gpointer        data)
+vinagre_notebook_page_switched (GtkNotebook *notebook,
+				GtkWidget   *page,
+				gint         page_num,
+				gpointer     data)
 {
   VinagreNotebook *nb = VINAGRE_NOTEBOOK (notebook);
   VinagreTab *tab;
@@ -383,13 +387,11 @@ vinagre_notebook_page_switched (GtkNotebook     *notebook,
 static void
 vinagre_notebook_page_removed_cb (VinagreNotebook *nb)
 {
-  gint n;
-
   if ((gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb)) == 0) &&
       (vinagre_window_is_fullscreen (nb->priv->window)))
     vinagre_window_toggle_fullscreen (nb->priv->window);
 
-vinagre_notebook_show_hide_tabs (nb);
+  vinagre_notebook_show_hide_tabs (nb);
 }
 
 static void
@@ -479,7 +481,7 @@ tab_auth_failed_cb (VinagreTab *tab, const gchar *msg, VinagreNotebook *nb)
 
   emphasis = g_strdup_printf ("<i>%s</i>", name);
   /* Translators: %s is a host name or IP address. */
-  g_string_printf (message, _("Authentication to host %s has failed"),
+  g_string_printf (message, _("Authentication for host %s has failed"),
 		   emphasis);
   if (msg)
   	g_string_append_printf (message, " (%s)", msg);
@@ -558,8 +560,7 @@ build_tab_label (VinagreNotebook *nb,
 		    tab);
 
   /* setup spinner */
-  spinner = vinagre_spinner_new ();
-  vinagre_spinner_set_size (VINAGRE_SPINNER (spinner), GTK_ICON_SIZE_MENU);
+  spinner = gtk_spinner_new();
   gtk_box_pack_start (GTK_BOX (label_hbox), spinner, FALSE, FALSE, 0);
 
   /* setup site icon */
@@ -614,7 +615,6 @@ vinagre_notebook_add_tab (VinagreNotebook *nb,
 			  gint           position)
 {
   GtkWidget      *label;
-  GtkActionGroup *action_group;
   int            pos;
 
   g_return_if_fail (VINAGRE_IS_NOTEBOOK (nb));
@@ -668,7 +668,6 @@ vinagre_notebook_close_tab (VinagreNotebook *nb,
 			    VinagreTab      *tab)
 {
   gint           position;
-  GtkActionGroup *action_group;
   GtkNotebook    *notebook;
   VinagreTab     *previous_active_tab;
 
@@ -734,6 +733,12 @@ vinagre_notebook_close_active_tab (VinagreNotebook *nb)
   vinagre_notebook_close_tab (nb, nb->priv->active_tab);
 }
 
+/**
+ * vinagre_notebook_get_active_tab:
+ * @nb: A Notebook
+ *
+ * Return value: (transfer none):
+ */
 VinagreTab *
 vinagre_notebook_get_active_tab (VinagreNotebook *nb)
 {
@@ -742,6 +747,12 @@ vinagre_notebook_get_active_tab (VinagreNotebook *nb)
   return nb->priv->active_tab;
 }
 
+/**
+ * vinagre_notebook_get_tabs:
+ * @nb: A Notebook
+ *
+ * Return value: (transfer none) (element-type VinagreTab):
+ */
 GSList *
 vinagre_notebook_get_tabs (VinagreNotebook *nb)
 {
