@@ -25,9 +25,11 @@
 #include <errno.h>
 #include <time.h>
 #include <sys/types.h>
+#include <fcntl.h>
 #include <string.h>
 
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <gdk/gdkkeysyms.h>
 
 #include "vinagre-window.h"
@@ -40,8 +42,8 @@
 #include "vinagre-ui.h"
 #include "vinagre-window-private.h"
 #include "vinagre-bookmarks-entry.h"
-#include "vinagre-plugin.h"
 #include "vinagre-plugins-engine.h"
+#include "vinagre-dirs.h"
 
 #ifdef VINAGRE_ENABLE_AVAHI
 #include "vinagre-mdns.h"
@@ -58,10 +60,16 @@ vinagre_window_dispose (GObject *object)
 {
   VinagreWindow *window = VINAGRE_WINDOW (object);
 
+  peas_engine_garbage_collect (PEAS_ENGINE (vinagre_plugins_engine_get_default ()));
+
   if (!window->priv->dispose_has_run)
     {
-      vinagre_plugins_engine_deactivate_plugins (vinagre_plugins_engine_get_default (),
-						 window);
+      peas_extension_set_call (window->priv->extensions,
+			       "deactivate",
+			       window);
+
+      g_object_unref (window->priv->extensions);
+      peas_engine_garbage_collect (PEAS_ENGINE (vinagre_plugins_engine_get_default ()));
       window->priv->dispose_has_run = TRUE;
     }
 
@@ -80,6 +88,8 @@ vinagre_window_dispose (GObject *object)
       window->priv->update_recents_menu_ui_id = 0;
     }
 
+  peas_engine_garbage_collect (PEAS_ENGINE (vinagre_plugins_engine_get_default ()));
+
   G_OBJECT_CLASS (vinagre_window_parent_class)->dispose (object);
 }
 
@@ -102,15 +112,15 @@ vinagre_window_show_hide_controls (VinagreWindow *window)
 {
   if (window->priv->fullscreen)
     {
-      window->priv->fav_panel_visible = GTK_WIDGET_VISIBLE (window->priv->fav_panel);
+      window->priv->fav_panel_visible = gtk_widget_get_visible (window->priv->fav_panel);
       gtk_widget_hide (window->priv->fav_panel);
 
-      window->priv->toolbar_visible = GTK_WIDGET_VISIBLE (window->priv->toolbar);
+      window->priv->toolbar_visible = gtk_widget_get_visible (window->priv->toolbar);
       gtk_widget_hide (window->priv->toolbar);
 
       gtk_widget_hide (window->priv->menubar);
 
-      window->priv->statusbar_visible = GTK_WIDGET_VISIBLE (window->priv->statusbar);
+      window->priv->statusbar_visible = gtk_widget_get_visible (window->priv->statusbar);
       gtk_widget_hide (window->priv->statusbar);
 
       gtk_notebook_set_show_tabs (GTK_NOTEBOOK (window->priv->notebook), FALSE);
@@ -193,7 +203,7 @@ vinagre_window_class_init (VinagreWindowClass *klass)
 }
 
 static void
-menu_item_select_cb (GtkItem       *proxy,
+menu_item_select_cb (GtkMenuItem   *proxy,
 		     VinagreWindow *window)
 {
   GtkAction *action;
@@ -212,7 +222,7 @@ menu_item_select_cb (GtkItem       *proxy,
 }
 
 static void
-menu_item_deselect_cb (GtkItem       *proxy,
+menu_item_deselect_cb (GtkMenuItem   *proxy,
                        VinagreWindow *window)
 {
   gtk_statusbar_pop (GTK_STATUSBAR (window->priv->statusbar),
@@ -492,7 +502,7 @@ vinagre_window_populate_bookmarks (VinagreWindow *window,
   GtkAction             *action;
   VinagreWindowPrivate  *p = window->priv;
   VinagreConnection     *conn;
-  VinagrePlugin         *plugin;
+  VinagreProtocol       *ext;
 
   for (l = entries; l; l = l->next)
     {
@@ -530,8 +540,10 @@ vinagre_window_populate_bookmarks (VinagreWindow *window,
 
 	  case VINAGRE_BOOKMARKS_ENTRY_NODE_CONN:
 	    conn = vinagre_bookmarks_entry_get_conn (entry);
-	    plugin = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
-								    vinagre_connection_get_protocol (conn));
+	    ext = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
+								 vinagre_connection_get_protocol (conn));
+	    if (!ext)
+	     continue;
 
 	    action_name = vinagre_connection_get_best_name (conn);
 	    action_label = vinagre_utils_escape_underscores (action_name, -1);
@@ -549,7 +561,7 @@ vinagre_window_populate_bookmarks (VinagreWindow *window,
 				     NULL);
 	    g_object_set (G_OBJECT (action),
 			  "icon-name",
-			  vinagre_plugin_get_icon_name (plugin),
+			  vinagre_protocol_get_icon_name (ext),
 			  NULL);
 	    g_object_set_data (G_OBJECT (action), "conn", conn);
 	    gtk_action_group_add_action (p->bookmarks_list_action_group,
@@ -704,12 +716,13 @@ create_notebook (VinagreWindow *window)
 static gboolean
 vinagre_window_check_first_run (VinagreWindow *window)
 {
-  gchar *filename;
+  gchar *dir, *filename;
 
-  filename = g_build_filename (g_get_user_data_dir (),
-			       "vinagre",
+  dir = vinagre_dirs_get_user_data_dir ();
+  filename = g_build_filename (dir,
 			       "first_run",
 			       NULL);
+  g_free (dir);
 
   if (!g_file_test (filename, G_FILE_TEST_EXISTS))
     {
@@ -743,10 +756,37 @@ vinagre_window_check_first_run (VinagreWindow *window)
   return FALSE;
 }
 
+static void
+extension_added (PeasExtensionSet *extensions,
+		 PeasPluginInfo   *info,
+		 PeasExtension    *exten,
+		 gpointer          user_data)
+{
+  peas_extension_call (exten, "activate");
+}
+
+static void
+extension_removed (PeasExtensionSet *extensions,
+		   PeasPluginInfo   *info,
+		   PeasExtension    *exten,
+		   gpointer          user_data)
+{
+  peas_extension_call (exten, "deactivate");
+}
+
+static void
+protocol_added_removed_cb (VinagrePluginsEngine *engine,
+			   VinagreProtocol      *protocol,
+			   VinagreWindow        *window)
+{
+  vinagre_window_update_bookmarks_list_menu (window);
+}
+
 static void
 vinagre_window_init (VinagreWindow *window)
 {
   GtkWidget *main_box;
+  VinagrePluginsEngine *engine;
 
   gtk_window_set_default_icon_name ("vinagre");
 
@@ -765,7 +805,7 @@ vinagre_window_init (VinagreWindow *window)
   create_statusbar (window, main_box);
 
   /* Add the main area */
-  window->priv->hpaned = gtk_hpaned_new ();
+  window->priv->hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
   gtk_box_pack_start (GTK_BOX (main_box), 
   		      window->priv->hpaned, 
   		      TRUE, 
@@ -797,13 +837,39 @@ vinagre_window_init (VinagreWindow *window)
                             window);
 #endif
 
-  vinagre_plugins_engine_activate_plugins (vinagre_plugins_engine_get_default (),
-					   window);
+  engine = vinagre_plugins_engine_get_default ();
+  window->priv->extensions = peas_extension_set_new (PEAS_ENGINE (engine),
+						     PEAS_TYPE_ACTIVATABLE,
+						     "object", window,
+						     NULL);
+  g_signal_connect (window->priv->extensions,
+		    "extension-added",
+		    G_CALLBACK (extension_added),
+		    window);
+  g_signal_connect (window->priv->extensions,
+		    "extension-removed",
+		    G_CALLBACK (extension_removed),
+		    window);
+  peas_extension_set_call (window->priv->extensions, "activate");
 
+  g_signal_connect_after (engine,
+			  "protocol-added",
+			  G_CALLBACK (protocol_added_removed_cb),
+			  window);
+  g_signal_connect_after (engine,
+			  "protocol-removed",
+			  G_CALLBACK (protocol_added_removed_cb),
+			  window);
 
   g_idle_add ((GSourceFunc) vinagre_window_check_first_run, window);
 }
 
+/**
+ * vinagre_window_get_notebook:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 VinagreNotebook *
 vinagre_window_get_notebook (VinagreWindow *window)
 {
@@ -861,6 +927,12 @@ vinagre_window_toggle_fullscreen (VinagreWindow *window)
     gtk_window_fullscreen (GTK_WINDOW (window));
 }
 
+/**
+ * vinagre_window_get_statusbar:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkWidget *
 vinagre_window_get_statusbar (VinagreWindow *window)
 {
@@ -869,6 +941,12 @@ vinagre_window_get_statusbar (VinagreWindow *window)
   return window->priv->statusbar;
 }
 
+/**
+ * vinagre_window_get_toolbar:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkWidget *
 vinagre_window_get_toolbar (VinagreWindow *window)
 {
@@ -877,6 +955,12 @@ vinagre_window_get_toolbar (VinagreWindow *window)
   return window->priv->toolbar;
 }
 
+/**
+ * vinagre_window_get_menubar:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkWidget *
 vinagre_window_get_menubar (VinagreWindow *window)
 {
@@ -885,6 +969,12 @@ vinagre_window_get_menubar (VinagreWindow *window)
   return window->priv->menubar;
 }
 
+/**
+ * vinagre_window_get_initialized_action:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkActionGroup *
 vinagre_window_get_initialized_action (VinagreWindow *window)
 {
@@ -893,6 +983,12 @@ vinagre_window_get_initialized_action (VinagreWindow *window)
   return window->priv->machine_initialized_action_group;
 }
 
+/**
+ * vinagre_window_get_always_sensitive_action:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkActionGroup *
 vinagre_window_get_always_sensitive_action (VinagreWindow *window)
 {
@@ -901,6 +997,12 @@ vinagre_window_get_always_sensitive_action (VinagreWindow *window)
   return window->priv->always_sensitive_action_group;
 }
 
+/**
+ * vinagre_window_get_connected_action:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkActionGroup *
 vinagre_window_get_connected_action (VinagreWindow *window)
 {
@@ -909,6 +1011,12 @@ vinagre_window_get_connected_action (VinagreWindow *window)
   return window->priv->machine_connected_action_group;
 }
 
+/**
+ * vinagre_window_get_fav_panel:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkWidget *
 vinagre_window_get_fav_panel (VinagreWindow *window)
 {
@@ -925,6 +1033,12 @@ vinagre_window_close_active_tab	(VinagreWindow *window)
   vinagre_notebook_close_active_tab (window->priv->notebook);
 }
 
+/**
+ * vinagre_window_get_active_tab:
+ * @window: A window
+ *
+ * Return value: (allow-none) (transfer none):
+ */
 VinagreTab *
 vinagre_window_get_active_tab (VinagreWindow *window)
 {
@@ -933,6 +1047,12 @@ vinagre_window_get_active_tab (VinagreWindow *window)
   return vinagre_notebook_get_active_tab (window->priv->notebook);
 }
 
+/**
+ * vinagre_window_get_ui_manager:
+ * @window: A window
+ *
+ * Return value: (transfer none):
+ */
 GtkUIManager *
 vinagre_window_get_ui_manager (VinagreWindow *window)
 {
@@ -951,7 +1071,12 @@ add_connection (VinagreTab *tab, GList **res)
   *res = g_list_prepend (*res, conn);
 }
 
-/* Returns a newly allocated list with all the connections in the window */
+/**
+ * vinagre_window_get_connections: Returns a newly allocated
+ * list with all the connections in the window
+ * 
+ * Return value: (element-type VinagreConnection) (transfer full):
+ */
 GList *
 vinagre_window_get_connections (VinagreWindow *window)
 {
@@ -968,6 +1093,12 @@ vinagre_window_get_connections (VinagreWindow *window)
   return res;
 }
 
+/**
+ * vinagre_window_conn_exists:
+ * @window: A window
+ *
+ * Return value: (allow-none) (transfer none):
+ */
 VinagreTab *
 vinagre_window_conn_exists (VinagreWindow *window, VinagreConnection *conn)
 {
